/*
 * Copyright (C) 2005 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License.
 * You must obey the GNU General Public License in all respects for all of the code used
 * other than the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package  mir.entity;

import java.util.Map;
import java.util.List;

import mir.storage.DatabaseExc;
import mir.storage.DatabaseFailure;

/**
 * An <code>Entity</code> represents a persistent data object, typically
 *   stored in a database.<p>
 *
 * @version $Id: Entity.java,v 1.21.2.15 2005/12/24 11:43:34 zapata Exp $
 */

public interface Entity {
  /**
   * Sets the values of the Entity. (Only to be called by the Storage Object)
   *
   * @param aMap Map containing the new values of the Entity
   */

  public void setFieldValues(Map aMap);

  /**
   * Returns the primary key of the Entity.
   * @return String Id
   */
  public String getId();

  /**
   * Defines the primary key of the Entity (only to be set by the Database)
   * @param id
   */
  public void setId(String id);

  /**
   * Inserts Entity into the database via Database
   * @return Primary Key of the Entity
   * @exception DatabaseExc
   */
  public String insert() throws DatabaseExc;

  /**
   * Saves changes of this Entity to the database
   * @exception DatabaseFailure
   */
  public void update() throws DatabaseFailure;

  /**
   * Sets the value for a field. Issues a log message if the field name
   * supplied was not found in the Entity.
   * @param aFieldName The field name whose value has to be set
   * @param aValue The new value of the field
   * @exception DatabaseFailure
   */
  public void setFieldValue(String aFieldName, String aValue);

  /**
   * Returns the field names of the Entity
   */
  public List getFieldNames() throws DatabaseFailure;

  /**
   * Returns the value of a field by field name.
   * @param aFieldName The name of the field
   * @return value of the field
   */
  public String getFieldValue(String aFieldName);

  public boolean hasFieldValue(String aFieldName);

  /** Returns whether fieldName is a valid field name of this Entity.
   */
  public boolean hasField(String aFieldName) throws DatabaseFailure;
}

