/*
 * Copyright (C) 2005 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License.
 * You must obey the GNU General Public License in all respects for all of the code used
 * other than the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mir.media.image;

import mir.media.MediaExc;

import java.io.File;
import java.io.OutputStream;

public interface ImageProcessor {
  public void descaleImage(int aMaxSize) throws MediaExc;

  public void descaleImage(int aMaxSize, float aMinDescale) throws MediaExc;

  public void descaleImage(int aMaxSize, int aMinResize) throws MediaExc;

  public void descaleImage(int aMaxSize, float aMinDescale, int aMinResize) throws MediaExc;

  /**
   * Resizes an image to fit inside <code>aMaxWidth</code> and <code>aMaxHeight</code>, provided
   *    this requires at least <code>aMinResize</code> pixels will be removed from either the width or
   *    the height
   */
  public void descaleImage(int aMaxWidth, int aMaxHeight, float aMinDescale, int aMinResize) throws MediaExc;

  public void scaleImage(float aScalingFactor) throws MediaExc;

  public int getWidth();
  public int getHeight();
  public int getSourceFileSize();
  public int getScaledFileSize();
  public int getScaledWidth();
  public int getScaledHeight();
  public void writeScaledData(OutputStream aStream, String anImageType) 
    throws MediaExc;
  public byte[] getScaledData(String anImageType) throws MediaExc;
  public void writeScaledData(File aFile, String anImageType) throws MediaExc;

  /**
   * call this when you're over using this object (removes temp files)
   */
  public void cleanup();
}




















